==> qtjambi-quick-debuginfo-macos-5.15.20.jar: sources/QtJambiQuick/QQuickImageProvider_shell.h <==
#ifndef QQUICKIMAGEPROVIDER_SHELL_H
#define QQUICKIMAGEPROVIDER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtQuick/qquickimageprovider.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QVariant>
#include <QtCore/qsize.h>
#include <QtGui/qimage.h>
#include <QtGui/qpixmap.h>
#include <QtQml/qqmlengine.h>
#include <QtJambi/RegistryAPI>


class QQuickImageProvider_shell : public QQuickImageProvider, public QtJambiShellInterface
{
public:
    QQuickImageProvider_shell(QQmlImageProviderBase::ImageType type0, QQmlImageProviderBase::Flags flags1 = QQmlImageProviderBase::Flags());
    ~QQuickImageProvider_shell() override;

    QQmlImageProviderBase::Flags flags() const override;
    QQmlImageProviderBase::ImageType imageType() const override;
    QImage requestImage(const QString& id0, QSize* size1, const QSize& requestedSize2) override;
    QPixmap requestPixmap(const QString& id0, QSize* size1, const QSize& requestedSize2) override;
    QQuickTextureFactory* requestTexture(const QString& id0, QSize* size1, const QSize& requestedSize2) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QQuickImageProvider_access : public QQuickImageProvider
{
    jint __qt_flags_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_imageType_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_requestImage_cref_QString_QSize_ptr_cref_QSize(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring id0, QtJambiNativeID size1, QtJambiNativeID requestedSize2);
    jobject __qt_requestPixmap_cref_QString_QSize_ptr_cref_QSize(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring id0, QtJambiNativeID size1, QtJambiNativeID requestedSize2);
    jobject __qt_requestTexture_cref_QString_QSize_ptr_cref_QSize(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring id0, QtJambiNativeID size1, QtJambiNativeID requestedSize2);
};

#endif // QQUICKIMAGEPROVIDER_SHELL_H

==> qtjambi-quick-debuginfo-macos-6.5.3.jar: sources/QtJambiQuick/QQuickImageProvider_shell.h <==
#ifndef QQUICKIMAGEPROVIDER_SHELL_H
#define QQUICKIMAGEPROVIDER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtQuick/qquickimageprovider.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qimage.h>
#include <QtGui/qpixmap.h>
#include <QtQml/qqmlengine.h>
#include <QtJambi/RegistryAPI>


class QQuickImageProvider_shell : public QQuickImageProvider, public QtJambiShellInterface
{
public:
    QQuickImageProvider_shell(QQmlImageProviderBase::ImageType type0, QQmlImageProviderBase::Flags flags1 = QQmlImageProviderBase::Flags());
    ~QQuickImageProvider_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QQmlImageProviderBase::Flags flags() const override;
    QQmlImageProviderBase::ImageType imageType() const override;
    QImage requestImage(const QString& id0, QSize* size1, const QSize& requestedSize2) override;
    QPixmap requestPixmap(const QString& id0, QSize* size1, const QSize& requestedSize2) override;
    QQuickTextureFactory* requestTexture(const QString& id0, QSize* size1, const QSize& requestedSize2) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QQuickImageProvider_access : public QQuickImageProvider
{
    jint __qt_flags(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_imageType(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_requestImage_cref_QString_QSize_ptr_cref_QSize(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring id0, QtJambiNativeID size1, QtJambiNativeID requestedSize2);
    jobject __qt_requestPixmap_cref_QString_QSize_ptr_cref_QSize(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring id0, QtJambiNativeID size1, QtJambiNativeID requestedSize2);
    jobject __qt_requestTexture_cref_QString_QSize_ptr_cref_QSize(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring id0, QtJambiNativeID size1, QtJambiNativeID requestedSize2);
};

#endif // QQUICKIMAGEPROVIDER_SHELL_H
